#
# spec file for package vorta
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vorta
Version:        0.6.10
Release:        lp151.1.1
Summary:        Desktop Backup Client based on BorgBackup
License:        GPL-3.0-only
Group:          Productivity/Archiving/Backup
Url:            https://github.com/borgbase/vorta
Source:         https://github.com/borgbase/%{name}/archive/v%{version}.tar.gz
Source1:        vorta.desktop
# PATCH-FIX-OPENSUSE
Patch0:         fix-dependencies.patch
# PATCH-FIX-UPSTREAM
Patch1:         fix-qtoolbox-titles.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3-APScheduler
BuildRequires:  python3-QDarkStyle
BuildRequires:  python3-appdirs
BuildRequires:  python3-keyring
BuildRequires:  python3-paramiko
BuildRequires:  python3-peewee
BuildRequires:  python3-psutil
BuildRequires:  python3-pytest-runner
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-qt5
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools-git
BuildRequires:  update-desktop-files
Requires:       borgbackup
Requires:       python3-APScheduler
Requires:       python3-QDarkStyle
Requires:       python3-appdirs
Requires:       python3-keyring
Requires:       python3-paramiko
Requires:       python3-peewee
Requires:       python3-psutil
Requires:       python3-python-dateutil
Requires:       python3-qt5
BuildArch:      noarch

%description
Vorta is a backup client for Linux desktops. It integrates BorgBackup with
the desktop environment to protect data from disk failure,
ransomware and theft.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
export LANG=en_US.UTF-8
%python3_build

%install
export LANG=en_US.UTF-8
%python3_install
install -d %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
install -m644 src/vorta/assets/icons/hdd-o-active-dark.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/vorta.png
%suse_update_desktop_file -i vorta
%fdupes %{buildroot}%{python3_sitelib}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/vorta
%{_datadir}/applications/vorta.desktop
%{_datadir}/icons/hicolor/*/apps/vorta.png
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info

%changelog
* Mon Feb 25 2019 Antonio Larrosa <alarrosa@suse.com>
- Add fix-qtoolbox-titles.patch to fix a problem with QToolBox tab
  titles being cut at a fixed width independently of the title text
  or tab width.
* Mon Feb 25 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.10
  * Also set tray icon according to detected theme.
    Fixes gh#borgbase/vorta#199
  * Avoid deadlock when calling subprocess.Popen().
    Fixes gh#borgbase/vorta#187
  * Remove translation functions for Borg logging messages.
    Fixes gh#borgbase/vorta#197
  * Implement autostart for Linux
  * Add French and Italian translations
  * Update compressor selection: add zlib, add zstd,8, descriptions.
    Fixes gh#borgbase/vorta#145
  * Add tooltip to "add profile" button. Fixes gh#borgbase/vorta#183
- Update to version 0.6.8
  * Implement add profile button
  * Translation Bugfixes
* Fri Feb  8 2019 Antonio Larrosa <alarrosa@suse.com>
- Set LANG to use UTF-8 and fix builds in Leap 15.1
* Thu Feb  7 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.7
  * Separate light/dark settings for icon and theme.
    Fixes gh#borgbase/vorta#171
  * Ask for confirmation on delete (and small fixes)
    (gh#borgbase/vorta#176)
  * Show/Hide the main window in KDE when clicking on the tray icon
    (gh#borgbase/vorta#143)
  * Add debug tools for i18n UI layout checking (gh#borgbase/vorta#160)
  * Fix crash due to zombie processes (gh#borgbase/vorta#174)
  * Use ellipsis the Qt way in the archive table (gh#borgbase/vorta#169)
  * Fix Issue "Crash when cancelling "add new profile"
    gh#borgbase/vorta#168" (gh#borgbase/vorta#170)
- Update to version 0.6.6
  * Add light icons and dark stylesheet. Fixes gh#borgbase/vorta#151
    (gh#borgbase/vorta#155)
  * Implement feature to delete specific archive (gh#borgbase/vorta#164)
  * Programmatically detect theme color (for macOS) (gh#borgbase/vorta#150)
  * Add app name to tray menu and window title (gh#borgbase/vorta#153)
  * Improve archive mount feature. Fixes gh#borgbase/vorta#131. By @antlarr
    (gh#borgbase/vorta#156)
  * Translation-related improvements and German translation
    (gh#borgbase/vorta#146)
  * Skip sockets when reading private keys (gh#borgbase/vorta#147)
  * Remove leftover Sentry references. Fixes gh#borgbase/vorta#127
    (gh#borgbase/vorta#142)
  * Make the main window resizeable (gh#borgbase/vorta#130)
- Drop fix-umount.patch which was already merged upstream
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize description.
* Thu Jan 17 2019 alarrosa@suse.com
- Use %%python3* macros to build and install
- Fix fdupes call
- Add desktop file and install application icon
* Wed Jan 16 2019 alarrosa@suse.com
- Initial release of vorta 0.6.5
